@@ -121,6 +121,12 @@ class CursorTests(ConnectingTestCase):
         nref2 = sys.getrefcount(foo)
         self.assertEqual(nref1, nref2)
 
+    def test_modify_closed(self):
+        cur = self.conn.cursor()
+        cur.close()
+        sql = cur.mogrify("select %s", (10,))
+        self.assertEqual(sql, b"select 10")
+
     def test_bad_placeholder(self):
         cur = self.conn.cursor()
         self.assertRaises(psycopg2.ProgrammingError,
@@ -592,6 +598,20 @@ class CursorTests(ConnectingTestCase):
 
             self.assertEqual(victim_conn.closed, 2)
 
+    @skip_before_postgres(8, 2)
+    def test_rowcount_on_executemany_returning(self):
+        cur = self.conn.cursor()
+        cur.execute("create table execmany(id serial primary key, data int)")
+        cur.executemany(
+            "insert into execmany (data) values (%s)",
+            [(i,) for i in range(4)])
+        self.assertEqual(cur.rowcount, 4)
+
+        cur.executemany(
+            "insert into execmany (data) values (%s) returning data",
+            [(i,) for i in range(5)])
+        self.assertEqual(cur.rowcount, 5)
+
 
 def test_suite():
     return unittest.TestLoader().loadTestsFromName(__name__)
